@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: mar  6 2018 (10:42) 
 ## Version: 
-## Last-Updated: apr 10 2018 (09:34) 
+## Last-Updated: apr 26 2018 (13:15) 
 ##           By: Brice Ozenne
-##     Update #: 59
+##     Update #: 60
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -61,13 +61,6 @@ test_that("error when using transform", {
     expect_error(sCorrect(e))
 })
 
-## ** error for lvm with cluster
-m <- lvm(Y~X1)
-e <- estimate(m, data = d, cluster = 1:NROW(d))
-test_that("error when using cluster", {
-    expect_error(sCorrect(e))
-})
-
 ## * sCorrect for nlme objects
 
 ## ** warning for the satterthwaite approx. with REML
