@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: jan 22 2018 (11:45) 
 ## Version: 
-## Last-Updated: mar 26 2018 (17:34) 
+## Last-Updated: maj  2 2018 (09:55) 
 ##           By: Brice Ozenne
-##     Update #: 15
+##     Update #: 18
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -40,7 +40,7 @@ test_that("Score 1 link",{
     GS.score <- modelsearch(e.base, silent = TRUE)
     index.coef <- which(GS.score$res[,"Index"]=="Y~X1")
 
-    test.score <- summary(modelsearch2(e.base, statistic = "score", method.p.adjust = "holm", trace = 0), display = FALSE)
+    test.score <- summary(modelsearch2(e.base, statistic = "score", method.p.adjust = "holm", trace = 0), print = FALSE)
 
     
     expect_equivalent(GS.score$test[index.coef,"Test Statistic"],test.score$data[1,"statistic"])
@@ -53,7 +53,7 @@ test_that("Wald 1 link",{
     test.GS <- compare2(e.GS, par = "Y~X1" , bias.correct = FALSE, as.lava = FALSE)
     
     test.Wald <- summary(modelsearch2(e.base, link = "Y~X1", df = FALSE, bias.correct = FALSE,
-                                       statistic = "Wald", method.p.adjust = "max", trace = 0), display = FALSE)
+                                       statistic = "Wald", method.p.adjust = "max", trace = 0), print = FALSE)
 
     expect_equivalent(abs(test.GS[1,"statistic"]), test.Wald$data[1,"statistic"])
     expect_equal(test.GS[1,"p-value"], test.Wald$data[1,"p.value"], tolerance = 1e-5)
@@ -63,7 +63,7 @@ test_that("Wald 1 link",{
     test.GS <- compare2(e.GS, par  = "Y~X1", bias.correct = TRUE, as.lava = FALSE)
     
     test.Wald <- summary(modelsearch2(e.base, link = "Y~X1", df = TRUE, bias.correct = TRUE,
-                                       statistic = "Wald", method.p.adjust = "max", trace = 0), display = FALSE)
+                                       statistic = "Wald", method.p.adjust = "max", trace = 0), print = FALSE)
 
     expect_equivalent(abs(test.GS[1,"statistic"]), test.Wald$data[1,"statistic"])
     expect_equal(test.GS[1,"p-value"], test.Wald$data[1,"p.value"], tolerance = 1e-5)
